@@ -353,7 +353,7 @@ render_contact (GtkHTMLStream *html_stream, EContact *contact)
 	accum_multival_attribute (accum, contact, _("Yahoo"), E_CONTACT_IM_YAHOO, YAHOO_ICON, 0);
 
 	if (accum->len > 0)
-		gtk_html_stream_printf (html_stream, accum->str);
+		gtk_html_stream_printf (html_stream, "%s", accum->str);
 
 	end_block (html_stream);
 
@@ -368,7 +368,7 @@ render_contact (GtkHTMLStream *html_stream, EContact *contact)
 
 	if (accum->len > 0) {
 		start_block (html_stream, _("work"));
-		gtk_html_stream_printf (html_stream, accum->str);
+		gtk_html_stream_printf (html_stream, "%s", accum->str);
 		end_block (html_stream);
 	}
 
@@ -383,7 +383,7 @@ render_contact (GtkHTMLStream *html_stream, EContact *contact)
 
 	if (accum->len > 0) {
 		start_block (html_stream, _("personal"));
-		gtk_html_stream_printf (html_stream, accum->str);
+		gtk_html_stream_printf (html_stream, "%s", accum->str);
 		end_block (html_stream);
 	}
 
@@ -412,7 +412,8 @@ eab_contact_display_render_normal (EABContactDisplay *display, EContact *contact
 	gtk_html_stream_write (html_stream, "<body>\n", 7);
 
 	if (contact) {
-		char *str, *html;
+		const char *str;
+		char *html;
 		EContactPhoto *photo;
 
 		gtk_html_stream_printf (html_stream, "<table cellspacing=\"20\" border=\"0\"><td valign=\"top\">");
@@ -437,7 +438,7 @@ eab_contact_display_render_normal (EABContactDisplay *display, EContact *contact
 		}
 
 
-		if (e_contact_get_const (contact, E_CONTACT_IS_LIST))
+		if (e_contact_get (contact, E_CONTACT_IS_LIST))
 			render_contact_list (html_stream, contact);
 		else
 			render_contact (html_stream, contact);
@@ -465,7 +466,8 @@ eab_contact_display_render_compact (EABContactDisplay *display, EContact *contac
 	gtk_html_stream_write (html_stream, "<body>\n", 7);
 
 	if (contact) {
-		char *str, *html;
+		const char *str;
+		char *html;
 		EContactPhoto *photo;
 
 		gtk_html_stream_printf (html_stream,
@@ -661,7 +663,7 @@ eab_contact_display_new (void)
 static void
 eab_contact_display_init (GObject *object)
 {
-	gtk_html_construct (object);
+	gtk_html_construct ((GtkHTML *)object);
 }
 
 static void
