@@ -38,12 +38,13 @@
 #include <bonobo/bonobo-generic-factory.h>
 #include <bonobo-activation/bonobo-activation.h>
 #include <libedataserver/e-source.h>
-#include "e-util/e-passwords.h"
+#include <libedataserverui/e-passwords.h>
 #include "e-util/e-icon-factory.h"
 #include "alarm.h"
 #include "alarm-queue.h"
 #include "alarm-notify.h"
 #include "config-data.h"
+#include <camel/camel-object.h>
 
 
 
@@ -153,17 +154,21 @@ main (int argc, char **argv)
 
 	g_idle_add ((GSourceFunc) init_alarm_service, NULL);
 
+	/* FIXME Ideally we should not use camel libraries in calendar, though it is the case
+	   currently for attachments. Remove this once that is fixed. 
+	   Initialise global camel_object_type */
+	camel_object_get_type();
+
 	bonobo_main ();
 
 	bonobo_object_unref (BONOBO_OBJECT (factory));
 	factory = NULL;
 
-	alarm_queue_done ();
-	alarm_done ();
-
 	if (alarm_notify_service)
 		bonobo_object_unref (BONOBO_OBJECT (alarm_notify_service));
 
+	alarm_done ();
+
 	e_passwords_shutdown ();
 	gnome_sound_shutdown ();
 
