@@ -22,12 +22,9 @@
 #define _COMP_EDITOR_UTIL_H_
 
 #include <gtk/gtkwidget.h>
-#include <bonobo/bonobo-control.h>
-#include <bonobo/bonobo-event-source.h>
-#include "Evolution-Addressbook-SelectNames.h"
 #include "comp-editor-page.h"
 
-void comp_editor_dates (CompEditorPageDates *date, CalComponent *comp);
+void comp_editor_dates (CompEditorPageDates *date, ECalComponent *comp);
 void comp_editor_free_dates (CompEditorPageDates *dates);
 
 void comp_editor_date_label (CompEditorPageDates *dates, GtkWidget *label);
@@ -38,18 +35,6 @@ GtkWidget *comp_editor_new_date_edit (gboolean show_date, gboolean show_time,
 struct tm comp_editor_get_current_time (GtkObject *object, gpointer data);
 
 
-GNOME_Evolution_Addressbook_SelectNames comp_editor_create_contacts_component (void);
-GtkWidget * comp_editor_create_contacts_control (GNOME_Evolution_Addressbook_SelectNames corba_select_names);
-void comp_editor_connect_contacts_changed (GtkWidget *contacts_entry,
-					   BonoboListenerCallbackFn changed_cb,
-					   gpointer changed_cb_data);
-void comp_editor_show_contacts_dialog (GNOME_Evolution_Addressbook_SelectNames corba_select_names);
-
-void comp_editor_contacts_to_widget (GtkWidget *contacts_entry,
-				     CalComponent *comp);
-void comp_editor_contacts_to_component (GtkWidget *contacts_entry,
-					CalComponent *comp);
-
 char *comp_editor_strip_categories (const char *categories);
 
 #endif
