@@ -1,7 +1,6 @@
 /* Evolution calendar - Data model for ETable
  *
- * Copyright (C) 2000 Ximian, Inc.
- * Copyright (C) 2000 Ximian, Inc.
+ * Copyright (C) 2004 Ximian, Inc.
  *
  * Authors: Rodrigo Moya <rodrigo@ximian.com>
  *
@@ -19,20 +18,24 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
+
 #include <string.h>
 #include <libgnome/gnome-i18n.h>
-#include <gal/util/e-util.h>
 #include "e-cal-model-calendar.h"
 #include "e-cell-date-edit-text.h"
+#include "itip-utils.h"
 #include "misc.h"
+#include "dialogs/recur-comp.h"
+#include "dialogs/send-comp.h"
 
 struct _ECalModelCalendarPrivate {
+	guint reserved;
 };
 
-static void ecmc_class_init (ECalModelCalendarClass *klass);
-static void ecmc_init (ECalModelCalendar *model, ECalModelCalendarClass *klass);
-static void ecmc_finalize (GObject *object);
+static void e_cal_model_calendar_finalize (GObject *object);
 static int ecmc_column_count (ETableModel *etm);
 static void *ecmc_value_at (ETableModel *etm, int col, int row);
 static void ecmc_set_value_at (ETableModel *etm, int col, int row, const void *value);
@@ -46,21 +49,16 @@ static char *ecmc_value_to_string (ETableModel *etm, int col, const void *value)
 static void ecmc_fill_component_from_model (ECalModel *model, ECalModelComponent *comp_data,
 					    ETableModel *source_model, gint row);
 
-static GObjectClass *parent_class = NULL;
-
-E_MAKE_TYPE (e_cal_model_calendar, "ECalModelCalendar", ECalModelCalendar, ecmc_class_init,
-	     ecmc_init, E_TYPE_CAL_MODEL);
+G_DEFINE_TYPE (ECalModelCalendar, e_cal_model_calendar, E_TYPE_CAL_MODEL);
 
 static void
-ecmc_class_init (ECalModelCalendarClass *klass)
+e_cal_model_calendar_class_init (ECalModelCalendarClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	ETableModelClass *etm_class = E_TABLE_MODEL_CLASS (klass);
 	ECalModelClass *model_class = E_CAL_MODEL_CLASS (klass);
 
-	parent_class = g_type_class_peek_parent (klass);
-
-	object_class->finalize = ecmc_finalize;
+	object_class->finalize = e_cal_model_calendar_finalize;
 
 	etm_class->column_count = ecmc_column_count;
 	etm_class->value_at = ecmc_value_at;
@@ -76,7 +74,7 @@ ecmc_class_init (ECalModelCalendarClass *klass)
 }
 
 static void
-ecmc_init (ECalModelCalendar *model, ECalModelCalendarClass *klass)
+e_cal_model_calendar_init (ECalModelCalendar *model)
 {
 	ECalModelCalendarPrivate *priv;
 
@@ -87,7 +85,7 @@ ecmc_init (ECalModelCalendar *model, ECalModelCalendarClass *klass)
 }
 
 static void
-ecmc_finalize (GObject *object)
+e_cal_model_calendar_finalize (GObject *object)
 {
 	ECalModelCalendarPrivate *priv;
 	ECalModelCalendar *model = (ECalModelCalendar *) object;
@@ -100,8 +98,8 @@ ecmc_finalize (GObject *object)
 		model->priv = NULL;
 	}
 
-	if (parent_class->finalize)
-		parent_class->finalize (object);
+	if (G_OBJECT_CLASS (e_cal_model_calendar_parent_class)->finalize)
+		G_OBJECT_CLASS (e_cal_model_calendar_parent_class)->finalize (object);
 }
 
 /* ETableModel methods */
@@ -112,22 +110,41 @@ ecmc_column_count (ETableModel *etm)
 }
 
 static ECellDateEditValue *
-get_dtend (ECalModelComponent *comp_data)
+get_dtend (ECalModelCalendar *model, ECalModelComponent *comp_data)
 {
 	struct icaltimetype tt_end;
 
 	if (!comp_data->dtend) {
-		icaltimezone *zone;
+		icalproperty *prop;
+		icaltimezone *zone, *model_zone;
+		gboolean got_zone = FALSE;
 
-		tt_end = icalcomponent_get_dtend (comp_data->icalcomp);
-		if (!icaltime_is_valid_time (tt_end))
+		prop = icalcomponent_get_first_property (comp_data->icalcomp, ICAL_DTEND_PROPERTY);
+		if (!prop)
+			return NULL;
+
+		tt_end = icalproperty_get_dtend (prop);
+
+		if (icaltime_get_tzid (tt_end)
+		    && e_cal_get_timezone (comp_data->client, icaltime_get_tzid (tt_end), &zone, NULL))
+			got_zone = TRUE;
+
+		if (e_cal_model_get_flags (E_CAL_MODEL (model)) & E_CAL_MODEL_FLAGS_EXPAND_RECURRENCES) {
+			if (got_zone) {
+				tt_end = icaltime_from_timet_with_zone (comp_data->instance_end, tt_end.is_date, zone);
+				if ((model_zone = e_cal_model_get_timezone (E_CAL_MODEL (model))))
+					icaltimezone_convert_time (&tt_end, zone, model_zone);
+			} else
+				tt_end = icaltime_from_timet (comp_data->instance_end, tt_end.is_date);
+		}
+
+		if (!icaltime_is_valid_time (tt_end) || icaltime_is_null_time (tt_end))
 			return NULL;
 
 		comp_data->dtend = g_new0 (ECellDateEditValue, 1);
 		comp_data->dtend->tt = tt_end;
 
-		if (icaltime_get_tzid (tt_end)
-		    && e_cal_get_timezone (comp_data->client, icaltime_get_tzid (tt_end), &zone, NULL)) 
+		if (got_zone)
 			comp_data->dtend->zone = zone;
 		else
 			comp_data->dtend->zone = NULL;
@@ -145,7 +162,7 @@ get_location (ECalModelComponent *comp_data)
 	if (prop)
 		return (void *) icalproperty_get_location (prop);
 
-	return NULL;
+	return "";
 }
 
 static void *
@@ -184,7 +201,7 @@ ecmc_value_at (ETableModel *etm, int col, int row)
 	g_return_val_if_fail (row >= 0 && row < e_table_model_row_count (etm), NULL);
 
 	if (col < E_CAL_MODEL_FIELD_LAST)
-		return E_TABLE_MODEL_CLASS (parent_class)->value_at (etm, col, row);
+		return E_TABLE_MODEL_CLASS (e_cal_model_calendar_parent_class)->value_at (etm, col, row);
 
 	comp_data = e_cal_model_get_component_at (E_CAL_MODEL (model), row);
 	if (!comp_data)
@@ -192,7 +209,7 @@ ecmc_value_at (ETableModel *etm, int col, int row)
 
 	switch (col) {
 	case E_CAL_MODEL_CALENDAR_FIELD_DTEND :
-		return get_dtend (comp_data);
+		return get_dtend (model, comp_data);
 	case E_CAL_MODEL_CALENDAR_FIELD_LOCATION :
 		return get_location (comp_data);
 	case E_CAL_MODEL_CALENDAR_FIELD_TRANSPARENCY :
@@ -317,6 +334,8 @@ static void
 ecmc_set_value_at (ETableModel *etm, int col, int row, const void *value)
 {
 	ECalModelComponent *comp_data;
+	CalObjModType mod = CALOBJ_MOD_ALL;
+	ECalComponent *comp;
 	ECalModelCalendar *model = (ECalModelCalendar *) etm;
 
 	g_return_if_fail (E_IS_CAL_MODEL_CALENDAR (model));
@@ -324,7 +343,7 @@ ecmc_set_value_at (ETableModel *etm, int col, int row, const void *value)
 	g_return_if_fail (row >= 0 && row < e_table_model_row_count (etm));
 
 	if (col < E_CAL_MODEL_FIELD_LAST) {
-		E_TABLE_MODEL_CLASS (parent_class)->set_value_at (etm, col, row, value);
+		E_TABLE_MODEL_CLASS (e_cal_model_calendar_parent_class)->set_value_at (etm, col, row, value);
 		return;
 	}
 
@@ -332,6 +351,20 @@ ecmc_set_value_at (ETableModel *etm, int col, int row, const void *value)
 	if (!comp_data)
 		return;
 
+	comp = e_cal_component_new ();
+	if (!e_cal_component_set_icalcomponent (comp, icalcomponent_new_clone (comp_data->icalcomp))) {
+		g_object_unref (comp);
+		return;
+	}
+
+	/* ask about mod type */
+	if (e_cal_component_is_instance (comp)) {
+		if (!recur_component_dialog (comp_data->client, comp, &mod, NULL, FALSE)) {
+			g_object_unref (comp);
+			return;
+		}
+	}
+
 	switch (col) {
 	case E_CAL_MODEL_CALENDAR_FIELD_DTEND :
 		set_dtend (comp_data, value);
@@ -344,12 +377,18 @@ ecmc_set_value_at (ETableModel *etm, int col, int row, const void *value)
 		break;
 	}
 
-	/* FIXME ask about mod type */
-	if (!e_cal_modify_object (comp_data->client, comp_data->icalcomp, CALOBJ_MOD_ALL, NULL)) {
+	if (e_cal_modify_object (comp_data->client, comp_data->icalcomp, CALOBJ_MOD_ALL, NULL)) {
+		if (itip_organizer_is_user (comp, comp_data->client) &&
+		    send_component_dialog (NULL, comp_data->client, comp, FALSE))
+			itip_send_comp (E_CAL_COMPONENT_METHOD_REQUEST, comp,
+					comp_data->client, NULL, NULL);
+	} else {
 		g_warning (G_STRLOC ": Could not modify the object!");
 		
 		/* FIXME Show error dialog */
 	}
+
+	g_object_unref (comp);
 }
 
 static gboolean
@@ -362,7 +401,7 @@ ecmc_is_cell_editable (ETableModel *etm, int col, int row)
 	g_return_val_if_fail (row >= -1 || (row >= 0 && row < e_table_model_row_count (etm)), FALSE);
 
 	if (col < E_CAL_MODEL_FIELD_LAST)
-		return E_TABLE_MODEL_CLASS (parent_class)->is_cell_editable (etm, col, row);
+		return E_TABLE_MODEL_CLASS (e_cal_model_calendar_parent_class)->is_cell_editable (etm, col, row);
 
 	switch (col) {
 	case E_CAL_MODEL_CALENDAR_FIELD_DTEND :
@@ -380,7 +419,7 @@ ecmc_duplicate_value (ETableModel *etm, int col, const void *value)
 	g_return_val_if_fail (col >= 0 && col < E_CAL_MODEL_CALENDAR_FIELD_LAST, NULL);
 
 	if (col < E_CAL_MODEL_FIELD_LAST)
-		return E_TABLE_MODEL_CLASS (parent_class)->duplicate_value (etm, col, value);
+		return E_TABLE_MODEL_CLASS (e_cal_model_calendar_parent_class)->duplicate_value (etm, col, value);
 
 	switch (col) {
 	case E_CAL_MODEL_CALENDAR_FIELD_DTEND :
@@ -408,7 +447,7 @@ ecmc_free_value (ETableModel *etm, int col, void *value)
 	g_return_if_fail (col >= 0 && col < E_CAL_MODEL_CALENDAR_FIELD_LAST);
 
 	if (col < E_CAL_MODEL_FIELD_LAST) {
-		E_TABLE_MODEL_CLASS (parent_class)->free_value (etm, col, value);
+		E_TABLE_MODEL_CLASS (e_cal_model_calendar_parent_class)->free_value (etm, col, value);
 		return;
 	}
 
@@ -428,7 +467,7 @@ ecmc_initialize_value (ETableModel *etm, int col)
 	g_return_val_if_fail (col >= 0 && col < E_CAL_MODEL_CALENDAR_FIELD_LAST, NULL);
 
 	if (col < E_CAL_MODEL_FIELD_LAST)
-		return E_TABLE_MODEL_CLASS (parent_class)->initialize_value (etm, col);
+		return E_TABLE_MODEL_CLASS (e_cal_model_calendar_parent_class)->initialize_value (etm, col);
 
 	switch (col) {
 	case E_CAL_MODEL_CALENDAR_FIELD_DTEND :
@@ -447,7 +486,7 @@ ecmc_value_is_empty (ETableModel *etm, int col, const void *value)
 	g_return_val_if_fail (col >= 0 && col < E_CAL_MODEL_CALENDAR_FIELD_LAST, TRUE);
 
 	if (col < E_CAL_MODEL_FIELD_LAST)
-		return E_TABLE_MODEL_CLASS (parent_class)->value_is_empty (etm, col, value);
+		return E_TABLE_MODEL_CLASS (e_cal_model_calendar_parent_class)->value_is_empty (etm, col, value);
 
 	switch (col) {
 	case E_CAL_MODEL_CALENDAR_FIELD_DTEND :
@@ -463,10 +502,10 @@ ecmc_value_is_empty (ETableModel *etm, int col, const void *value)
 static char *
 ecmc_value_to_string (ETableModel *etm, int col, const void *value)
 {
-	g_return_val_if_fail (col >= 0 && col < E_CAL_MODEL_CALENDAR_FIELD_LAST, NULL);
+	g_return_val_if_fail (col >= 0 && col < E_CAL_MODEL_CALENDAR_FIELD_LAST, g_strdup (""));
 
 	if (col < E_CAL_MODEL_FIELD_LAST)
-		return E_TABLE_MODEL_CLASS (parent_class)->value_to_string (etm, col, value);
+		return E_TABLE_MODEL_CLASS (e_cal_model_calendar_parent_class)->value_to_string (etm, col, value);
 
 	switch (col) {
 	case E_CAL_MODEL_CALENDAR_FIELD_DTEND :
@@ -476,7 +515,7 @@ ecmc_value_to_string (ETableModel *etm, int col, const void *value)
 		return g_strdup (value);
 	}
 
-	return NULL;
+	return g_strdup ("");
 }
 
 /* ECalModel class methods */
