@@ -32,6 +32,7 @@
 #include "itip-utils.h"
 #include "misc.h"
 #include "e-calendar-marshal.h"
+#include "calendar-config.h"
 
 typedef struct {
 	ECal *client;
@@ -100,6 +101,8 @@ static void remove_client (ECalModel *model, ECalModelClient *client_data);
 enum {
 	TIME_RANGE_CHANGED,
 	ROW_APPENDED,
+	CAL_VIEW_PROGRESS,
+	CAL_VIEW_DONE,
 	LAST_SIGNAL
 };
 
@@ -148,6 +151,23 @@ e_cal_model_class_init (ECalModelClass *klass)
 			      NULL, NULL,
 			      g_cclosure_marshal_VOID__VOID,
 			      G_TYPE_NONE, 0);
+	signals[CAL_VIEW_PROGRESS] =
+		g_signal_new ("cal_view_progress",
+			      G_TYPE_FROM_CLASS (klass),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (ECalModelClass, cal_view_progress),
+			      NULL, NULL,
+	                      e_calendar_marshal_VOID__STRING_INT_INT,
+			      G_TYPE_NONE, 3, G_TYPE_STRING, G_TYPE_INT, G_TYPE_INT);
+	signals[CAL_VIEW_DONE] =
+		g_signal_new ("cal_view_done",
+			      G_TYPE_FROM_CLASS (klass),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (ECalModelClass, cal_view_done),
+			      NULL, NULL,
+			      e_calendar_marshal_VOID__INT_INT,
+			      G_TYPE_NONE, 2, G_TYPE_INT, G_TYPE_INT);
+
 }
 
 static void
@@ -1295,23 +1315,42 @@ add_instance_cb (ECalComponent *comp, time_t instance_start, time_t instance_end
 static void
 set_instance_times (ECalModelComponent *comp_data, icaltimezone *zone)
 {
-	struct icaltimetype recur_time, start_time, end_time, itt;
+	struct icaltimetype recur_time, start_time, end_time;
 
 	recur_time = icalcomponent_get_recurrenceid (comp_data->icalcomp);
 	start_time = icalcomponent_get_dtstart (comp_data->icalcomp);
 	end_time = icalcomponent_get_dtend (comp_data->icalcomp);
 
-	if (e_cal_util_component_is_instance (comp_data->icalcomp)) {
-		itt = icaltime_convert_to_zone (recur_time, icaltimezone_get_utc_timezone ());
-		comp_data->instance_start = icaltime_as_timet (itt);
-	} else {
-		comp_data->instance_start = icaltime_as_timet (start_time);
-	}
+	comp_data->instance_start = icaltime_as_timet (start_time);
 
 	comp_data->instance_end = comp_data->instance_start +
 		(icaltime_as_timet (end_time) - icaltime_as_timet (start_time));
 }
 
+/* We do this check since the calendar items are downloaded from the server in the open_method,
+   since the default timezone might not be set there */
+static void
+ensure_dates_are_in_default_zone (icalcomponent *icalcomp)
+{
+	icaltimetype dt;
+	icaltimezone *zone = calendar_config_get_icaltimezone ();
+
+	if (!zone)
+		return;
+
+	dt = icalcomponent_get_dtstart (icalcomp);
+	if (dt.is_utc) {
+		dt = icaltime_convert_to_zone (dt, zone);
+		icalcomponent_set_dtstart (icalcomp, dt);
+	}
+
+	dt = icalcomponent_get_dtend (icalcomp);
+	if (dt.is_utc) {
+		dt = icaltime_convert_to_zone (dt, zone);
+		icalcomponent_set_dtend (icalcomp, dt);
+	}
+}
+
 static void
 e_cal_view_objects_added_cb (ECalView *query, GList *objects, gpointer user_data)
 {
@@ -1332,9 +1371,11 @@ e_cal_view_objects_added_cb (ECalView *query, GList *objects, gpointer user_data
 			pos = get_position_in_array (priv->objects, comp_data);
 			e_table_model_row_deleted (E_TABLE_MODEL (model), pos);
 
-			g_ptr_array_remove (priv->objects, comp_data);
-			e_cal_model_free_component_data (comp_data);
-		}
+ 			g_ptr_array_remove (priv->objects, comp_data);
+ 			e_cal_model_free_component_data (comp_data);
+ 		}
+
+		ensure_dates_are_in_default_zone (l->data);
 
 		if ((priv->flags & E_CAL_MODEL_FLAGS_EXPAND_RECURRENCES)) {
 			RecurrenceExpansionData rdata;
@@ -1422,20 +1463,25 @@ static void
 e_cal_view_progress_cb (ECalView *query, const char *message, int percent, gpointer user_data)
 {
 	ECalModel *model = (ECalModel *) user_data;
+	ECal *client = e_cal_view_get_client (query);
 
 	g_return_if_fail (E_IS_CAL_MODEL (model));
 
-	/* FIXME Update status bar */
+	g_signal_emit (G_OBJECT (model), signals[CAL_VIEW_PROGRESS], 0, message, 
+			percent, e_cal_get_source_type (client));
 }
 
 static void
 e_cal_view_done_cb (ECalView *query, ECalendarStatus status, gpointer user_data)
 {
  	ECalModel *model = (ECalModel *) user_data;
+	ECal *client = e_cal_view_get_client (query);
 
 	g_return_if_fail (E_IS_CAL_MODEL (model));
 
-	/* FIXME Clear status bar */
+	/* emit the signal on the model and let the view catch it to display */
+	g_signal_emit (G_OBJECT (model), signals[CAL_VIEW_DONE], 0, status,
+			e_cal_get_source_type (client));
 }
 
 static void
