@@ -509,7 +509,7 @@ e_calendar_table_init (ECalendarTable *cal_table)
 	g_signal_connect (e_table, "key_press", G_CALLBACK (e_calendar_table_on_key_press), cal_table);
 	g_signal_connect (e_table, "popup_menu", G_CALLBACK (e_calendar_table_on_popup_menu), cal_table);
 
-	a11y = gtk_widget_get_accessible (e_table);
+	a11y = gtk_widget_get_accessible ((GtkWidget *)e_table);
 	if (a11y)
 		atk_object_set_name (a11y, _("Task Table"));
 }
@@ -589,7 +589,7 @@ e_calendar_table_open_selected (ECalendarTable *cal_table)
 	ECalModelComponent *comp_data;
 	icalproperty *prop;
 
-	comp_data = get_selected_comp (cal_table);
+	comp_data = e_calendar_table_get_selected_comp (cal_table);
 	prop = icalcomponent_get_first_property (comp_data->icalcomp, ICAL_ATTENDEE_PROPERTY);
 	if (comp_data != NULL)
 		e_calendar_table_open_task (cal_table, comp_data, prop ? TRUE : FALSE);
@@ -1025,7 +1025,7 @@ e_calendar_table_on_save_as (EPopup *ep, EPopupItem *pitem, void *data)
 		return;
 	}
 	
-	fprintf (file, ical_string);
+	fprintf (file, "%s", ical_string);
 	g_free (ical_string);
 	fclose (file);
 }
