@@ -41,7 +41,7 @@
 #include "mail-autofilter.h"
 #include "mail-component.h"
 #include "em-utils.h"
-#include "widgets/misc/e-error.h"
+#include "e-util/e-error.h"
 
 #include "em-vfolder-context.h"
 #include "em-vfolder-rule.h"
@@ -52,6 +52,10 @@
 #include "em-filter-editor.h"
 #include "filter/filter-option.h"
 
+#include <camel/camel-internet-address.h>
+#include <camel/camel-mime-message.h>
+
+#define d(x)
 
 static void
 rule_match_recipients (RuleContext *context, FilterRule *rule, CamelInternetAddress *iaddr)
@@ -385,7 +389,7 @@ mail_filter_rename_uri(CamelStore *store, const char *olduri, const char *newuri
 	
 	changed = rule_context_rename_uri((RuleContext *)fc, eolduri, enewuri, g_str_equal);
 	if (changed) {
-		printf("Folder rename '%s' -> '%s' changed filters, resaving\n", olduri, newuri);
+		d(printf("Folder rename '%s' -> '%s' changed filters, resaving\n", olduri, newuri));
 		if (rule_context_save((RuleContext *)fc, user) == -1)
 			g_warning("Could not write out changed filter rules\n");
 		rule_context_free_uri_list((RuleContext *)fc, changed);
@@ -431,7 +435,7 @@ mail_filter_delete_uri(CamelStore *store, const char *uri)
 		g_string_free(s, TRUE);
 		gtk_widget_show(dialog);
 		
-		printf("Folder deleterename '%s' changed filters, resaving\n", euri);
+		d(printf("Folder delete/rename '%s' changed filters, resaving\n", euri));
 		if (rule_context_save ((RuleContext *) fc, user) == -1)
 			g_warning ("Could not write out changed filter rules\n");
 		rule_context_free_uri_list ((RuleContext *) fc, deleted);
