@@ -36,7 +36,7 @@ extern "C" {
 #include "camel/camel-mime-message.h"
 #include "camel/camel-operation.h"
 
-#include "e-util/e-msgport.h"
+#include "libedataserver/e-msgport.h"
 #include "e-util/e-account.h"
 
 void mail_append_mail (CamelFolder *folder, CamelMimeMessage *message, CamelMessageInfo *info,
@@ -57,6 +57,11 @@ void mail_get_message (CamelFolder *folder, const char *uid,
 		       void *data,
 		       EThread *thread);
 
+void
+mail_get_messagex(CamelFolder *folder, const char *uid,
+		  void (*done) (CamelFolder *folder, const char *uid, CamelMimeMessage *msg, void *data, CamelException *),
+		  void *data, EThread *thread);
+
 /* get several messages */
 void mail_get_messages (CamelFolder *folder, GPtrArray *uids,
 			void (*done) (CamelFolder *folder, GPtrArray *uids, GPtrArray *msgs, void *data),
